Bun is a fast, all-in-one toolkit for installing, bundling, running and testing JavaScript & TypeScript. To install: `npm i -g bun`

Joined July 2022
Bun's now leading the TypeScript checker race! As always, in @framer's monorepo: πŸ† bun check: 2.42s, 2.0 GB | v1.4.4 πŸ₯ˆ tsrs: 2.50s, 2.6 GB | v0.18 πŸ₯‰ tsc-ts: 5.9s, 5.3 GB | v0.6 TS 7.1 beta: 13.9s, 8.1 GB
Bun
@bunjavascript11h
Bun v1.4.4 - Fixes 271 issues, addressing 544 πŸ‘ - `bun fmt` is a fast Prettier-compatible code formatter - `bun check` gets 1.4x - 7.8x faster - New in Bun.SQL & WebSocket - Security fixes, including for Brotli, TLS certs, HTTP/3, and more bun.com/blog/bun-v1.4.4
5
7
6
163
12,404
Bun retweeted
Jarred Sumner
@jarredsumnerOct 19
In the next version of Bun bun check gets 1.7x - 7x faster
58
26
9
1,239
52,373
Bun retweeted
Moved an important API from Node β†’ @bunjavascript Latency p50: βˆ’25% p95: βˆ’60% p99: βˆ’80% Resources Memory: βˆ’63% CPU: βˆ’25%
7
4
3
168
19,119
Bun retweeted
Jarred Sumner
@jarredsumnerSep 29
An early preview of experimental Bun + JSC with ahead-of-time compilation For Claude Code's CLI: 24% faster startup, 48% lower memory, 46% lower CPU, and nearly 2x larger binary size
69
65
21
1,374
145,944
Bun retweeted
Jarred Sumner
@jarredsumnerSep 16
In the next version of Bun `Bun.FetchSession` gives you a `fetch` function with its own keepalive connection pool
23
19
6
626
46,421
Replying to @bunjavascript
@bunjavascript v1.4 😍
2
2
39
3,709
Bun retweeted
thank you bun
Bun
@bunjavascriptSep 4
Bun v1.4.1 reduces idle memory usage
3
7
4
398
27,153
In the next version of Bun Bigger BigInt
5
10
2
244
20,135
So far, it seems quite stable in terms of memory usage. Thanks, @bunjavascript @jarredsumner!
Bun
@bunjavascriptAug 20
Bun 1.4 - Fixes over 2,900 GitHub issues - +1,517 tests from the Node.js test suite - Reduces idle CPU by 5x - Reduces memory usage by up to 35% - Starts up to 50% faster on Linux - Rewrites Bun in Rust Thank you everyone who contributed since Bun 1.3! bun.com/blog/bun-v1.4
4
2
1
474
38,997
The Bun runtime on Vercel Functions now supports larger package sizes and extended max duration. β€’ Up to 5GB uncompressed β€’ Functions can run up to 30 minutes β€’ Available on Fluid compute in beta vercel.com/changelog/bun-run…
6
7
3
226
13,627
actually the bun 1.4.0 had not even landed, these were other optimizations now it has landed and the result is that memory use is down from ~300mb to ~100mb, an impressive -67% reduction!
guess when i moved to bun 1.4.0
5
6
217
16,599
Bun retweeted
Jarred Sumner
@jarredsumnerAug 21
In the next version of Bun Bun gets 2 MB smaller
36
20
11
1,416
103,830
Bun retweeted
Jarred Sumner
@jarredsumnerAug 21
Bun 1.4 is our smallest release yet
155
99
76
2,315
1,089,125
hunk test suite on Bun 1.4 takes noticeably less time (92% code coverage btw, we’re not savages)
Bun
@bunjavascriptAug 20
Bun 1.4 - Fixes over 2,900 GitHub issues - +1,517 tests from the Node.js test suite - Reduces idle CPU by 5x - Reduces memory usage by up to 35% - Starts up to 50% faster on Linux - Rewrites Bun in Rust Thank you everyone who contributed since Bun 1.3! bun.com/blog/bun-v1.4
4
2
87
10,247
Bun 1.4 is available in Vercel Functions. β€’ Supports WebSockets and π™±πšžπš—.πšœπšŽπš›πšŸπšŽ() β€’ Supports Next.js, Elysia, Hono and others β€’ Runs on Fluid with Active CPU billing Set "bunVersion": "1.4.x" in vercel.json to upgrade. vercel.com/changelog/bun-1-4…
17
22
8
530
84,168
In the next version of Bun `bun repl` gets an inline autocomplete
8
5
1
160
15,902
Deploy π™±πšžπš—.πšœπšŽπš›πšŸπšŽ() to Vercel Functions. Vercel's Bun runtime now supports π™±πšžπš—.πšœπšŽπš›πšŸπšŽ() as a function entrypoint, including WebSocket handlers. vercel.com/changelog/bun-ser…
19
12
8
317
92,757
Bun retweeted
Jarred Sumner
@jarredsumnerAug 4
In the next version of Bun `bun test --timings` records how long each test file takes `bun test --parallel --shard=i/N` uses timings to split CI shards via longest-processing-time-first scheduling, making large test suites run faster
24
13
2
398
29,814
Bun 1.4 πŸ™ŒπŸΌ @bunjavascript
6
13
1
436
32,867